summaryrefslogtreecommitdiffstats
path: root/kmail/snippetdlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/snippetdlg.cpp')
-rw-r--r--kmail/snippetdlg.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmail/snippetdlg.cpp b/kmail/snippetdlg.cpp
index 2229a763..25a64ae6 100644
--- a/kmail/snippetdlg.cpp
+++ b/kmail/snippetdlg.cpp
@@ -26,14 +26,14 @@
#include "kmessagebox.h"
/*
* Constructs a SnippetDlg as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-SnippetDlg::SnippetDlg( KActionCollection* ac, TQWidget* tqparent, const char* name, bool modal, WFlags fl )
- : SnippetDlgBase( tqparent, name, modal, fl ), actionCollection( ac )
+SnippetDlg::SnippetDlg( KActionCollection* ac, TQWidget* parent, const char* name, bool modal, WFlags fl )
+ : SnippetDlgBase( parent, name, modal, fl ), actionCollection( ac )
{
if ( !name )
setName( "SnippetDlg" );
@@ -26,14 +26,14 @@
#include "kmessagebox.h"
/*
- * Constructs a SnippetDlg as a child of 'tqparent', with the
+ * Constructs a SnippetDlg as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*